# Copyright 2022 Intrinsic Innovation LLC.
# Copyright 2022 DeepMind Technologies Limited.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""A sub-package defining different types of groups of factors."""

from pgmax.fgroup.enum import EnumFactorGroup
from pgmax.fgroup.enum import PairwiseFactorGroup
from pgmax.fgroup.fgroup import FactorGroup
from pgmax.fgroup.fgroup import SingleFactorGroup
from pgmax.fgroup.logical import ANDFactorGroup
from pgmax.fgroup.logical import LogicalFactorGroup
from pgmax.fgroup.logical import ORFactorGroup
from pgmax.fgroup.pool import PoolFactorGroup
